Other commands
**************

Unit-testing
============
.. cmake-module:: ../../test.cmake
.. cmake-module:: ../../gtest.cmake

Xacro
=====
.. cmake-module:: ../../xacro.cmake

IDL
===
.. cmake-module:: ../../idl.cmake

Version script
==============

.. cmake-module:: ../../version-script.cmake

Cython
======

.. cmake-module:: ../../cython/cython.cmake

Make targets
============

The following macros define targets which are added to the Makefile:

- :ref:`dist <target-dist>`: generates a tarball;
- :ref:`distcheck <target-distcheck>`: checks the generated tarball;
- :ref:`release <target-release>`: releases a stable version of the current package.

.. cmake-module:: ../../dist.cmake
.. cmake-module:: ../../distcheck.cmake
.. cmake-module:: ../../release.cmake
